aboutsummaryrefslogtreecommitdiffstats
path: root/e2fsck/e2fsck.h
diff options
context:
space:
mode:
authorTahsin Erdogan <tahsin@google.com>2017-07-23 21:20:41 -0400
committerTheodore Ts'o <tytso@mit.edu>2017-07-23 21:20:41 -0400
commit0b4ffc2747fd51da903f2f5f083a762f0aafc37b (patch)
tree1e3e05e1eb6f7d45d3d660ea497d2f905113d4b9 /e2fsck/e2fsck.h
parent50cb5332dd7576a61b6571299355e084d2984b56 (diff)
downloadandroid_external_e2fsprogs-0b4ffc2747fd51da903f2f5f083a762f0aafc37b.tar.gz
android_external_e2fsprogs-0b4ffc2747fd51da903f2f5f083a762f0aafc37b.tar.bz2
android_external_e2fsprogs-0b4ffc2747fd51da903f2f5f083a762f0aafc37b.zip
e2fsck: update quota inode accounting for ea_inode feature
Extended attribute inodes are charged to all referencing inodes. Update e2fsck so that it can correctly track inode quota charges. Signed-off-by: Tahsin Erdogan <tahsin@google.com> Signed-off-by: Theodore Ts'o <tytso@mit.edu>
Diffstat (limited to 'e2fsck/e2fsck.h')
-rw-r--r--e2fsck/e2fsck.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/e2fsck/e2fsck.h b/e2fsck/e2fsck.h
index b25c5eb9..ca414ccb 100644
--- a/e2fsck/e2fsck.h
+++ b/e2fsck/e2fsck.h
@@ -269,9 +269,10 @@ struct e2fsck_struct {
ext2_refcount_t refcount_extra;
/*
* Quota blocks to be charged for each ea block.
*/
- ext2_refcount_t ea_block_quota;
+ ext2_refcount_t ea_block_quota_blocks;
+ ext2_refcount_t ea_block_quota_inodes;
/*
* ea_inode references from attr entries.
@@ -269,9 +269,10 @@ struct e2fsck_struct {
ext2_refcount_t refcount_extra;
/*
- * Quota blocks to be charged for each ea block.
+ * Quota blocks and inodes to be charged for each ea block.
*/